# Quelques macros Python de mon cru
# Qui permettent d'intéragir avec la feuille courante du classeur courant
#

#importation de la fonction permettant de créer
#une session de travail avec Calc de LibreOffice
#scriptforge est une librairie de LibreOffice
#https://help.libreoffice.org/latest/en-US/text/sbasic/shared/03/lib_ScriptForge.html
from scriptforge import CreateScriptService

#première macro - écriture dans une cellule
#pas d'argument en entrée, accès direct aux feuilles
def hello_world(args=None):
    #création d'une session
    doc = CreateScriptService("Calc")
    #écrire dans la cellule A1 de la feuille courante
    #du classeur courant
    doc.SetValue("A1","Hello World avec Python")
    #c'est une macro = une procédure, ne renvoie rien
    return None


#lecture et écriture
def get_set_value(args=None):
    #création du service
    doc = CreateScriptService("Calc")
    #lecture en A1 (feuille + classeur courants)
    value = doc.GetValue("A1")
    #calcul
    value = value + 1
    #écriture en A2
    doc.SetValue("A2", value)
    return None

#tant que pas cellule vide
#lecture des valeurs en colonne A
#écriture en colonne B si paire ou impaire
#on simplifie en considérant que les valeurs
#sont toutes entières
def test_paires_impaires(args=None):
    #service
    doc = CreateScriptService("Calc")
    #id de ligne
    i = 0
    #cellule de départ en A1
    cur_cell = doc.Offset("A1",0,0)
    #tant que la cellule contient une valeur
    while (doc.GetValue(cur_cell) != ""):
        #i - décalage de ligne par rapport à A1
        #1 - décalage de colonne par rapport à A1 -> colonne B
        voisin = doc.Offset("A1",i,1)
        #lecture + test + écriture en B
        if (doc.GetValue(cur_cell) % 2 == 0):
            doc.SetValue(voisin,"paire")
        else:
            doc.SetValue(voisin,"impaire")
        #passage à la ligne suivante
        i = i + 1
        cur_cell = doc.Offset("A1",i,0)
    #mettre FIN si cellule vide en A
    doc.SetValue(doc.Offset("A1",i,1),"THE END")
    return None

#on considère la structure de la feuille connue
#le résultat de la simulation est en B8
#on récupère au fur et à mesure les résultats pour les
#copier en colonne D
#le nombre de simulation est demandé à l'utilisateur
#via une boîte de dialogue -> service "Basic"
def simulation(args=None):
    #service "Calc"
    doc = CreateScriptService("Calc")
    #service "Basic"
    bas = CreateScriptService("Basic")
    #boîte de dialogue : nombre d'essais
    n = bas.InputBox("Nombre","Simulations","100")
    n = int(n)
    #itérations
    for i in range(n):
        #récupération en B8
        res = doc.GetValue("B8")
        #écriture en colonne D
        #chaque écriture provoque un recalcul de la feuille
        # -> le résultat en B8 est mis à jour
        doc.SetValue(doc.Offset("D1",i+1,0),res)
    return None

